package Task::Lingua::PT;
use strict;

our $VERSION = '0.02';

=head1 NAME

Task::Lingua::PT - Replacement for the PT NLP tools Bundle

=head1 SYNOPSIS

Installs a set of NLP tools for the Portuguese language.

=head1 AUTHOR

Alberto Simoes, C<< <ambs at perl.pt> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-task-lingua-pt at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Task-Lingua-PT>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Task::Lingua::PT


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Task-Lingua-PT>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Task-Lingua-PT>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Task-Lingua-PT>

=item * Search CPAN

L<http://search.cpan.org/dist/Task-Lingua-PT/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2010 Alberto Simoes.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.


=cut

1; # End of Task::Lingua::PT
